
Python implementations of Sentinel 2 Toolbox L2 products & spectral indices

.. image:: https://github.com/UpstatePedro/sentipy/workflows/Run%20tests/badge.svg

sentipy is a small package that aims to do one thing well: provide an easy-to-use python API for processing sentinel
satellite raster data into useful biophysical estimates and spectral indices.

Installation
-------------

The sentipy package is built & published (with enormous gratitude) using `Poetry <https://python-poetry.org/>`_

.. code-block:: bash

    $ pip install sentipy

Documentation
-------------

.. image:: https://readthedocs.org/projects/sentipy/badge/?version=latest
   :target: https://sentipy.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

Documentation for the project is hosted at `Read the Docs <https://sentipy.rtfd.io>`_

Project status
--------------

This is a hobby project in the early stages of development, please do not rely on feature or API stability!